==> mx-bootrepair_18.12.tar.xz: mx-bootrepair-18.12/translations/mx-bootrepair_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as root.</source>
        <translation>Tem que executar este programa como root.</translation>
    </message>
</context>
<context>
    <name>mxbootrepair</name>
    <message>
        <location filename="../mxbootrepair.ui" line="20"/>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>MX Boot Repair</source>
        <translation>MX Reparador de Inicialização</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
        <translation>O MX Reparador de Inicialização é um utilitário que pode ser usado para reinstalar o gerenciador de inicialização GRUB no MBR (Master Boot Record) ou na partição root. Oferece as opções de reconstrução do arquivo de configuração do GRUB e de fazer uma cópia e restaurar o MBR ou o PBR.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>O que pretende fazer?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Cópia de segurança do MBR ou do PBR (apenas em computadores com BIOS)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="86"/>
        <source>Reinstall GRUB bootloader</source>
        <translation>Reinstalar o gerenciador de iniciação GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Reparar o arquivo de configuração do GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Restaurar MBR ou PBR a partir de cópia (apenas em computadores com BIOS)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="123"/>
        <location filename="../mxbootrepair.cpp" line="378"/>
        <source>Select Boot Method</source>
        <translation>Selecionar método de iniciação</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="141"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="144"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="147"/>
        <location filename="../mxbootrepair.ui" line="418"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="169"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Raíz (Partition Boot Record)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="172"/>
        <location filename="../mxbootrepair.cpp" line="380"/>
        <source>root</source>
        <translation>raíz (PBR)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="223"/>
        <location filename="../mxbootrepair.cpp" line="379"/>
        <source>Install on:</source>
        <translation>Instalar em:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="242"/>
        <source>Location:</source>
        <translation>Localização:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="264"/>
        <source>Select /boot location:</source>
        <translation>Selecione a localização de /boot</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="277"/>
        <source>EFI System Partition</source>
        <translation>Partição de Sistema EFI</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="280"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="407"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="410"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="460"/>
        <source>Display help </source>
        <translation>Mostrar a ajuda</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="463"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="471"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="512"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar alterações e sair</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="515"/>
        <location filename="../mxbootrepair.cpp" line="451"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="523"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="542"/>
        <source>Apply any changes</source>
        <translation>Aplicar alterações</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="545"/>
        <location filename="../mxbootrepair.cpp" line="78"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="96"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>O GRUB está sendo instalado em %1</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="111"/>
        <location filename="../mxbootrepair.cpp" line="134"/>
        <location filename="../mxbootrepair.cpp" line="164"/>
        <location filename="../mxbootrepair.cpp" line="266"/>
        <location filename="../mxbootrepair.cpp" line="300"/>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source>Could not mount </source>
        <translation>Não foi montado</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source> on /boot/efi</source>
        <translation> em /boot/efi</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="135"/>
        <location filename="../mxbootrepair.cpp" line="165"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Não foi possível definir o ambiente chroot.
Por favor volte a verificar a localização selecionada.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="152"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>O arquivo de configuração do GRUB (grub.cfg) está sendo refeito</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="186"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Guardando o MBR (ou o PBR) de %1</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="241"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>You are going to write the content of </source>
        <translation>Vai escrever o conteúdo de </translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source> to </source>
        <translation> em </translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>

Are you sure?</source>
        <translation>
    
Tem a certeza?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="247"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Restaurando MBR/PBR em %1 a partir da cópia.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="267"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Não foi encontrada a ESP (EFI System Partition) em qualquer dos discos do sistema. Criar uma ESP e voltar a tentar.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="294"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="295"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>O processo terminou com êxito.&lt;p&gt;&lt;b&gt;Gostaria de sair do MX Reparador de Inicialização?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="301"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>O processo terminou. Ocorreram erros.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="303"/>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="387"/>
        <source>Select GRUB location</source>
        <translation>Selecione a localização do GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="398"/>
        <source>Select Item to Back Up</source>
        <translation>Selecione o item a copiar para segurança</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="405"/>
        <source>Select Item to Restore</source>
        <translation>Selecione o item a restaurar</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <source>Select backup file name</source>
        <translation>Escolha o nome da cópia de segurança (backup).</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>No file was selected.</source>
        <translation>Não foi seleccionado qualquer arquivo.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Selecione a cópia de segurança (backup) do MBR ou do PBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="444"/>
        <source>About MX Boot Repair</source>
        <translation>Sobre o MX Reparador de Inicialização</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="447"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Programa simples de reparação da inicialização (boot) para o MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="448"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="449"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="450"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="472"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
</TS>

==> mx-bootrepair_19.1.tar.xz: mx-bootrepair-19.1/translations/mx-bootrepair_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>You must run this program as root.</source>
        <translation>Tem que executar este programa como root.</translation>
    </message>
</context>
<context>
    <name>mxbootrepair</name>
    <message>
        <location filename="../mxbootrepair.ui" line="20"/>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>MX Boot Repair</source>
        <translation>MX Reparador de Inicialização</translation>
    </message>
    <message>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR.</source>
        <translation type="vanished">O MX Reparador de Inicialização é um utilitário que pode ser usado para reinstalar o gerenciador de inicialização GRUB no MBR (Master Boot Record) ou na partição root. Oferece as opções de reconstrução do arquivo de configuração do GRUB e de fazer uma cópia e restaurar o MBR ou o PBR.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="58"/>
        <source>What would you like to do?</source>
        <translation>O que pretende fazer?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="79"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Cópia de segurança do MBR ou do PBR (apenas em computadores com BIOS)</translation>
    </message>
    <message>
        <source>Reinstall GRUB bootloader</source>
        <translation type="vanished">Reinstalar o gerenciador de iniciação GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="39"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="86"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="96"/>
        <source>Repair GRUB configuration file</source>
        <translation>Reparar o arquivo de configuração do GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="103"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Restaurar MBR ou PBR a partir de cópia (apenas em computadores com BIOS)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="123"/>
        <location filename="../mxbootrepair.cpp" line="378"/>
        <source>Select Boot Method</source>
        <translation>Selecionar método de iniciação</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="141"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="144"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="147"/>
        <location filename="../mxbootrepair.ui" line="417"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="169"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Raíz (Partition Boot Record)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="172"/>
        <location filename="../mxbootrepair.cpp" line="380"/>
        <source>root</source>
        <translation>raíz (PBR)</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="223"/>
        <location filename="../mxbootrepair.cpp" line="379"/>
        <source>Install on:</source>
        <translation>Instalar em:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="242"/>
        <source>Location:</source>
        <translation>Localização:</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="264"/>
        <source>Select /boot location:</source>
        <translation>Selecione a localização de /boot</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="277"/>
        <source>EFI System Partition</source>
        <translation>Partição de Sistema EFI</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="280"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="407"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="410"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="459"/>
        <source>Display help </source>
        <translation>Mostrar a ajuda</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="462"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="469"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="510"/>
        <source>Cancel any changes then quit</source>
        <translation>Cancelar alterações e sair</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="513"/>
        <location filename="../mxbootrepair.cpp" line="451"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="520"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="539"/>
        <source>Apply any changes</source>
        <translation>Aplicar alterações</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.ui" line="542"/>
        <location filename="../mxbootrepair.cpp" line="78"/>
        <source>Apply</source>
        <translation>Aplicar</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="96"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>O GRUB está sendo instalado em %1</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="111"/>
        <location filename="../mxbootrepair.cpp" line="134"/>
        <location filename="../mxbootrepair.cpp" line="164"/>
        <location filename="../mxbootrepair.cpp" line="266"/>
        <location filename="../mxbootrepair.cpp" line="300"/>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source>Could not mount </source>
        <translation>Não foi montado</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="112"/>
        <source> on /boot/efi</source>
        <translation> em /boot/efi</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="135"/>
        <location filename="../mxbootrepair.cpp" line="165"/>
        <source>Could not set up chroot environment.
Please double-check the selected location.</source>
        <translation>Não foi possível definir o ambiente chroot.
Por favor volte a verificar a localização selecionada.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="152"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>O arquivo de configuração do GRUB (grub.cfg) está sendo refeito</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="186"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Guardando o MBR (ou o PBR) de %1</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="241"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>You are going to write the content of </source>
        <translation>Vai escrever o conteúdo de </translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source> to </source>
        <translation> em </translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="242"/>
        <source>

Are you sure?</source>
        <translation>
    
Tem a certeza?</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="243"/>
        <location filename="../mxbootrepair.cpp" line="296"/>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="247"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Restaurando MBR/PBR em %1 a partir da cópia.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="267"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Não foi encontrada a ESP (EFI System Partition) em qualquer dos discos do sistema. Criar uma ESP e voltar a tentar.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="294"/>
        <source>Success</source>
        <translation>Sucesso</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="295"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>O processo terminou com êxito.&lt;p&gt;&lt;b&gt;Gostaria de sair do MX Reparador de Inicialização?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="301"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>O processo terminou. Ocorreram erros.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="303"/>
        <source>Back</source>
        <translation>Voltar</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="387"/>
        <source>Select GRUB location</source>
        <translation>Selecione a localização do GRUB</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="398"/>
        <source>Select Item to Back Up</source>
        <translation>Selecione o item a copiar para segurança</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="405"/>
        <source>Select Item to Restore</source>
        <translation>Selecione o item a restaurar</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="416"/>
        <source>Select backup file name</source>
        <translation>Escolha o nome da cópia de segurança (backup).</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="418"/>
        <location filename="../mxbootrepair.cpp" line="425"/>
        <source>No file was selected.</source>
        <translation>Não foi seleccionado qualquer arquivo.</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="423"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Selecione a cópia de segurança (backup) do MBR ou do PBR</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="444"/>
        <source>About MX Boot Repair</source>
        <translation>Sobre o MX Reparador de Inicialização</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="445"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="447"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Programa simples de reparação da inicialização (boot) para o MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="448"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="449"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="450"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../mxbootrepair.cpp" line="472"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
</TS>
